query GetRepository($owner: String!, $name: String!) {
  repository(owner: $owner, name: $name) {
    id
    name
    nameWithOwner
    url
    description
    owner {
      login
      url
    }
    isPrivate
    homepageUrl
  }
}