query GetProjectWorkflows($projectId: ID!, $first: Int!) {
  node(id: $projectId) {
    ... on ProjectV2 {
      workflows(first: $first) {
        nodes {
          id
          name
          path
          state
          url
          createdAt
          updatedAt
          fileContents
          ref
          runCount
        }
        pageInfo {
          hasNextPage
          endCursor
        }
      }
    }
  }
}