query($owner: String!, $repo: String!, $number: Int!) {
  repository(owner: $owner, name: $repo) {
    issue(number: $number) {
      id
      number
      title
      url
      state
      createdAt
      updatedAt
      author {
        login
      }
      body
    }
  }
}