query GetRepositoryPullRequests($owner: String!, $repo: String!, $first: Int = 20, $after: String) {
  repository(owner: $owner, name: $repo) {
    pullRequests(first: $first, after: $after) {
      nodes {
        id
        number
        title
        url
        state
        createdAt
        updatedAt
        author {
          login
        }
        body
      }
      pageInfo {
        hasNextPage
        endCursor
      }
    }
  }
}