query($id: ID!) {
  node(id: $id) {
    ... on User {
      id
      login
      name
      email
      bio
      company
      location
      websiteUrl
      url
      avatarUrl
      createdAt
      updatedAt
    }
  }
}