query getField($id: ID!) {
  node(id: $id) {
    ... on ProjectV2Field {
      id
      name
      dataType
    }
    ... on ProjectV2IterationField {
      id
      name
      dataType
    }
    ... on ProjectV2SingleSelectField {
      id
      name
      dataType
      options {
        id
        name
      }
    }
  }
}