query GetProjectTeams($projectId: ID!, $first: Int!) {
  node(id: $projectId) {
    ... on ProjectV2 {
      teams(first: $first) {
        nodes {
          id
          name
          slug
          description
          url
          privacy
        }
        pageInfo {
          hasNextPage
          endCursor
        }
      }
    }
  }
}