query($owner: String!, $repo: String!, $number: Int!, $first: Int = 20, $after: String) {
  repository(owner: $owner, name: $repo) {
    issue(number: $number) {
      comments(first: $first, after: $after) {
        nodes {
          id
          author {
            login
          }
          body
          createdAt
          updatedAt
          url
        }
        pageInfo {
          hasNextPage
          endCursor
        }
      }
    }
  }
}